@@ -18,7 +18,9 @@ DBISTATE_DECLARE;
 #define call_sv(x,y) perl_call_sv(x,y)
 #endif
 
-#define sqlite_error(h,xxh,rc,what) _sqlite_error(__FILE__, __LINE__, h, xxh, rc, what)
+#define sqlite_error(h,xxh,rc,what) _sqlite_error(aTHX_ __FILE__, __LINE__, h, xxh, rc, what)
+
+/* XXX: is there any good way to use pTHX_/aTHX_ here like above? */
 #if defined(__GNUC__) && (__GNUC__ > 2)
 #  define sqlite_trace(h,xxh,level,fmt...) _sqlite_tracef(__FILE__, __LINE__, h, xxh, level, fmt)
 #else
@@ -29,22 +31,22 @@ void
 sqlite_init(dbistate_t *dbistate)
 {
     dTHX;
-    DBIS = dbistate; /* XXX: looks like this can be removed, right? */
+    DBISTATE_INIT; /* Initialize the DBI macros  */
 }
 
 static void
-_sqlite_error(char *file, int line, SV *h, imp_xxh_t *imp_xxh, int rc, char *what)
+_sqlite_error(pTHX_ char *file, int line, SV *h, imp_xxh_t *imp_xxh, int rc, char *what)
 {
-    dTHX;
-
     DBIh_SET_ERR_CHAR(h, imp_xxh, Nullch, rc, what, Nullch, Nullch);
 
     /* #7753: DBD::SQLite error shouldn't include extraneous info */
     /* sv_catpvf(errstr, "(%d) at %s line %d", rc, file, line); */
-
     if ( DBIc_TRACE_LEVEL(imp_xxh) >= 3 ) {
-        PerlIO_printf(DBIc_LOGPIO(imp_xxh), "sqlite error %d recorded: %s at %s line %d\n",
-            rc, what, file, line);
+        PerlIO_printf(
+            DBIc_LOGPIO(imp_xxh),
+            "sqlite error %d recorded: %s at %s line %d\n",
+            rc, what, file, line
+        );
     }
 }
 
@@ -52,7 +54,7 @@ static void
 _sqlite_tracef(char *file, int line, SV *h, imp_xxh_t *imp_xxh, int level, const char *fmt, ...)
 {
     dTHX;
-    
+
     va_list ap;
     if ( DBIc_TRACE_LEVEL(imp_xxh) >= level ) {
         char format[8192];
@@ -67,7 +69,7 @@ static void
 _sqlite_tracef_noline(SV *h, imp_xxh_t *imp_xxh, int level, const char *fmt, ...)
 {
     dTHX;
-    
+
     va_list ap;
     if ( DBIc_TRACE_LEVEL(imp_xxh) >= level ) {
         char format[8192];
@@ -141,10 +143,8 @@ sqlite_db_login(SV *dbh, imp_dbh_t *imp_dbh, char *dbname, char *user, char *pas
 }
 
 int
-dbd_set_sqlite3_busy_timeout ( SV *dbh, int timeout )
+dbd_set_sqlite3_busy_timeout (pTHX_ SV *dbh, int timeout )
 {
-  dTHX;
-
   D_imp_dbh(dbh);
   if (timeout) {
     imp_dbh->timeout = timeout;
@@ -331,9 +331,8 @@ sqlite_quote(imp_dbh_t *imp_dbh, SV *val)
 }
 
 void
-sqlite_st_reset (SV *sth)
+sqlite_st_reset (pTHX_ SV *sth)
 {
-    dTHX;
     D_imp_sth(sth);
     if (DBIc_IMPSET(imp_sth))
         sqlite3_reset(imp_sth->stmt);
@@ -395,7 +394,8 @@ sqlite_st_execute (SV *sth, imp_sth_t *imp_sth)
             retval = sqlite3_bind_blob(imp_sth->stmt, i+1, data, len, SQLITE_TRANSIENT);
         }
         else {
-            /* guess a bit before binding */
+#if 0
+            /* stop guessing until we figure out better way to do this */
             const int numtype = looks_like_number(value);
             if ((numtype & (IS_NUMBER_IN_UV|IS_NUMBER_NOT_INT)) == IS_NUMBER_IN_UV) {
 #if defined(USE_64_BIT_INT)
@@ -408,6 +408,7 @@ sqlite_st_execute (SV *sth, imp_sth_t *imp_sth)
                 retval = sqlite3_bind_double(imp_sth->stmt, i+1, SvNV(value));
             }
             else {
+#endif
                 STRLEN len;
                 char *data;
                 if (imp_dbh->unicode) {
@@ -415,7 +416,9 @@ sqlite_st_execute (SV *sth, imp_sth_t *imp_sth)
                 }
                 data = SvPV(value, len);
                 retval = sqlite3_bind_text(imp_sth->stmt, i+1, data, len, SQLITE_TRANSIENT);
+#if 0
             }
+#endif
         }
 
         if (value) {
@@ -717,7 +720,12 @@ sqlite_db_STORE_attrib (SV *dbh, imp_dbh_t *imp_dbh, SV *keysv, SV *valuesv)
         return TRUE;
     }
     if (strEQ(key, "unicode")) {
+#if (PERL_REVISION <= 5) && ((PERL_VERSION < 8) || (PERL_VERSION == 8 && PERL_SUBVERSION < 5))
+      sqlite_trace(dbh, (imp_xxh_t*)imp_dbh, 2, "Unicode support is disabled for this version of perl.");
+      imp_dbh->unicode = 0;
+#else
       imp_dbh->unicode = !(! SvTRUE(valuesv));
+#endif
       return TRUE;
     }
     return FALSE;
@@ -733,7 +741,12 @@ sqlite_db_FETCH_attrib (SV *dbh, imp_dbh_t *imp_dbh, SV *keysv)
         return newSVpv(sqlite3_version,0);
     }
    if (strEQ(key, "unicode")) {
+#if (PERL_REVISION <= 5) && ((PERL_VERSION < 8) || (PERL_VERSION == 8 && PERL_SUBVERSION < 5))
+      sqlite_trace(dbh, (imp_xxh_t*)imp_dbh, 2, "Unicode support is disabled for this version of perl.");
+     return newSViv(0);
+#else
      return newSViv(imp_dbh->unicode ? 1 : 0);
+#endif
    }
 
     return NULL;
@@ -849,9 +862,8 @@ sqlite_st_FETCH_attrib (SV *sth, imp_sth_t *imp_sth, SV *keysv)
 }
 
 static void
-sqlite_db_set_result(sqlite3_context *context, SV *result, int is_error )
+sqlite_db_set_result(pTHX_ sqlite3_context *context, SV *result, int is_error )
 {
-    dTHX;
     STRLEN len;
     char *s;
 
@@ -930,19 +942,19 @@ sqlite_db_func_dispatcher(int is_unicode, sqlite3_context *context, int argc, sq
 
     /* Check for an error */
     if (SvTRUE(ERRSV) ) {
-        sqlite_db_set_result( context, ERRSV, 1);
+        sqlite_db_set_result(aTHX_ context, ERRSV, 1);
         POPs;
     } else if ( count != 1 ) {
         SV *err = sv_2mortal(newSVpvf( "function should return 1 argument, got %d",
                                        count ));
 
-        sqlite_db_set_result( context, err, 1);
+        sqlite_db_set_result(aTHX_ context, err, 1);
         /* Clear the stack */
         for ( i=0; i < count; i++ ) {
             POPs;
         }
     } else {
-        sqlite_db_set_result( context, POPs, 0 );
+        sqlite_db_set_result(aTHX_ context, POPs, 0 );
     }
 
     PUTBACK;
@@ -965,9 +977,8 @@ sqlite_db_func_dispatcher_no_unicode(sqlite3_context *context, int argc, sqlite3
 }
 
 void
-sqlite3_db_create_function( SV *dbh, const char *name, int argc, SV *func )
+sqlite3_db_create_function(pTHX_ SV *dbh, const char *name, int argc, SV *func )
 {
-    dTHX;
     D_imp_dbh(dbh);
     int retval;
 
@@ -990,9 +1001,8 @@ sqlite3_db_create_function( SV *dbh, const char *name, int argc, SV *func )
 }
 
 void
-sqlite3_db_enable_load_extension( SV *dbh, int onoff )
+sqlite3_db_enable_load_extension(pTHX_ SV *dbh, int onoff )
 {
-    dTHX;
     D_imp_dbh(dbh);
     int retval;
     
@@ -1013,9 +1023,8 @@ struct aggrInfo {
 };
 
 static void
-sqlite_db_aggr_new_dispatcher( sqlite3_context *context, aggrInfo *aggr_info )
+sqlite_db_aggr_new_dispatcher(pTHX_ sqlite3_context *context, aggrInfo *aggr_info )
 {
-    dTHX;
     dSP;
     SV *pkg = NULL;
     int count = 0;
@@ -1087,7 +1096,7 @@ sqlite_db_aggr_step_dispatcher (sqlite3_context *context,
 
     /* initialize on first step */
     if ( !aggr->inited ) {
-        sqlite_db_aggr_new_dispatcher( context, aggr );
+        sqlite_db_aggr_new_dispatcher(aTHX_ context, aggr );
     }
 
     if ( aggr->err || !aggr->aggr_inst ) 
@@ -1154,7 +1163,7 @@ sqlite_db_aggr_finalize_dispatcher( sqlite3_context *context )
         aggr = &myAggr;
         aggr->aggr_inst = NULL;
         aggr->err = NULL;
-        sqlite_db_aggr_new_dispatcher (context, aggr);
+        sqlite_db_aggr_new_dispatcher(aTHX_ context, aggr);
     } 
 
     if  ( ! aggr->err && aggr->aggr_inst ) {
@@ -1178,7 +1187,7 @@ sqlite_db_aggr_finalize_dispatcher( sqlite3_context *context )
                 POPs;
             }
         } else {
-            sqlite_db_set_result( context, POPs, 0 );
+            sqlite_db_set_result(aTHX_ context, POPs, 0 );
         }
         PUTBACK;
     }
@@ -1187,7 +1196,7 @@ sqlite_db_aggr_finalize_dispatcher( sqlite3_context *context )
         warn( "DBD::SQLite: error in aggregator cannot be reported to SQLite: %s",
             SvPV_nolen( aggr->err ) );
 
-        /* sqlite_db_set_result( context, aggr->err, 1 ); */
+        /* sqlite_db_set_result(aTHX_ context, aggr->err, 1 ); */
         SvREFCNT_dec( aggr->err );
         aggr->err = NULL;
     }
@@ -1202,9 +1211,8 @@ sqlite_db_aggr_finalize_dispatcher( sqlite3_context *context )
 }
 
 void
-sqlite3_db_create_aggregate( SV *dbh, const char *name, int argc, SV *aggr_pkg )
+sqlite3_db_create_aggregate(pTHX_ SV *dbh, const char *name, int argc, SV *aggr_pkg )
 {
-    dTHX;
     D_imp_dbh(dbh);
     int retval;
 
@@ -1290,9 +1298,8 @@ int sqlite_db_collation_dispatcher_utf8(
 
 
 void
-sqlite3_db_create_collation( SV *dbh, const char *name, SV *func )
+sqlite3_db_create_collation(pTHX_ SV *dbh, const char *name, SV *func )
 {
-    dTHX;
     D_imp_dbh(dbh);
     int rv, rv2;
     void *aa = "aa";
@@ -1352,9 +1359,8 @@ int sqlite_db_progress_handler_dispatcher( void *handler )
 
 
 void
-sqlite3_db_progress_handler( SV *dbh, int n_opcodes, SV *handler )
+sqlite3_db_progress_handler(pTHX_ SV *dbh, int n_opcodes, SV *handler )
 {
-    dTHX;
     D_imp_dbh(dbh);
 
     if (handler == &PL_sv_undef) {
